@@ -255,7 +255,7 @@ def set_variable_loader(config_dict, incremental_or_transfer, FromSratch=False):
 
 
 
-def edit_config(model_selected, config_dir, num_steps, label_map_path, record_dir, eval_number, annotation_type, 
+def edit_config(model_selected, input_config_dir, output_config_dir, num_steps, label_map_path, record_dir, eval_number, annotation_type, 
                 batch_size=None, learning_rate=None, resizer_size=None, incremental_or_transfer="transfer"):
     '''
         Wrapper to edit the essential values inside the base configuration protobuf file provided with an object-detection/segmentation checkpoint.
@@ -294,7 +294,7 @@ def edit_config(model_selected, config_dir, num_steps, label_map_path, record_di
     else:
         ckpt_path = os.path.join(model_selected, "ckpt")
 
-    configs = config_util.get_configs_from_pipeline_file(os.path.join(config_dir,'pipeline.config'))
+    configs = config_util.get_configs_from_pipeline_file(os.path.join(input_config_dir,'pipeline.config'))
     label_map = label_map_util.load_labelmap(label_map_path)
 
     config_util._update_train_steps(configs, num_steps)
@@ -323,8 +323,8 @@ def edit_config(model_selected, config_dir, num_steps, label_map_path, record_di
     update_num_classes(configs, label_map)
     config_proto = config_util.create_pipeline_proto_from_configs(configs)
     config_util._update_batch_size(configs, batch_size)
-    config_util.save_pipeline_config(config_proto, directory=config_dir)
-    print(f"Configuration successfully edited and saved at {config_dir}")
+    config_util.save_pipeline_config(config_proto, directory=output_config_dir)
+    print(f"Configuration successfully edited and saved at {output_config_dir}")
 
 
 def train(ckpt_dir='', config='', train_steps=1000, use_tpu=False, checkpoint_every_n=100,
